# Portage tree.
FROM gentoo/portage:latest as portage

# Build packages in /workdir.
FROM gentoo/stage3-amd64:latest as build
COPY --from=portage /var/db/repos/gentoo /var/db/repos/gentoo
RUN sed -i 's/-O2/-Os/' /etc/portage/make.conf
RUN echo -e '\n# Added by tastytea/gentoo-base:' >> /etc/portage/make.conf
# Bug 680456.
RUN echo 'FEATURES="-ipc-sandbox -mount-sandbox -network-sandbox -pid-sandbox \
    -sandbox -usersandbox nodoc noinfo noman"' >> /etc/portage/make.conf
RUN echo 'MAKEOPTS="-j1"' >> /etc/portage/make.conf
RUN echo 'USE="minimal -cracklib -gpg -ncurses -nls -pam -pcre -pcre-jit -perl \
    -readline -rsync-verify -xattr"' >> /etc/portage/make.conf
RUN eselect profile set default/linux/amd64/17.1
RUN quickpkg --include-config=y @world sys-libs/glibc
RUN emerge --root=/workdir --buildpkg=y --usepkg --quiet sys-apps/portage
RUN cp /etc/portage/make.conf /workdir/etc/portage/make.conf
RUN rm -r /workdir/usr/share/{i18n,locale,zoneinfo}

# Final image.
FROM scratch
LABEL maintainer="tastytea+docker@tastytea.de"
LABEL description="My base for Gentoo images (Without build dependencies)."
COPY --from=build /workdir /
RUN echo 'portage:x:250:250:portage:/var/tmp/portage:/bin/false' >> /etc/passwd
RUN echo 'portage::250:portage' >> /etc/group

# TODO: Mount distfiles.
# TODO: Use ccache with data on external volume.
